# SDE Simulator
This package provides a base class for SDE simulations.

## Usage

To use the class, import it:

`from sde_simulator import SDESimulatorBase`


Then, implement a new class inheriting from `SDESimulatorBase` snd implement the abstract methods.

Please look at the examples directory for implementation examples.